#
# spec file for package psutils
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           psutils
Version:        2.08
Release:        2.2
Summary:        Tools for Manipulating PostScript Files
License:        GPL-3.0-or-later
Group:          Productivity/Publishing/PS
URL:            https://github.com/rrthomas/psutils
Source:         %{url}/releases/download/v%{version}/psutils-%{version}.tar.gz
Requires:       libpaper-tools
Requires:       perl
Requires:       perl(IPC::Run3)

%description
This archive contains utilities for manipulating PostScript documents.
Page selection and rearrangement are supported, including arrangement
into signatures for booklet printing, and page merging for n-up
printing.

psbook      rearranges pages into signatures

psselect    selects pages and page ranges

pstops      performs general page rearrangement and selection

psnup       put multiple pages per physical sheet of paper

psresize    alter document paper size

epsffit     fits an EPSF file to a given bounding box

You will find a README in %{_docdir}/psutils/ which also
describes several Perl scripts for importing PostScript files. A manual
page for each ps utility is also included.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc README
%{_bindir}/epsffit
%{_bindir}/psbook
%{_bindir}/psnup
%{_bindir}/psresize
%{_bindir}/psselect
%{_bindir}/pstops
%{_bindir}/extractres
%{_bindir}/includeres
%{_bindir}/psjoin
%{_datadir}/psutils
%{_datadir}/psutils/PSUtils.pm
%{_mandir}/man1/epsffit.1*
%{_mandir}/man1/psbook.1*
%{_mandir}/man1/psnup.1*
%{_mandir}/man1/psresize.1*
%{_mandir}/man1/psselect.1*
%{_mandir}/man1/pstops.1*
%{_mandir}/man1/psutils.1*
%{_mandir}/man1/extractres.1*
%{_mandir}/man1/includeres.1*
%{_mandir}/man1/psjoin.1*

%changelog
* Mon Aug 22 2022 Dr. Werner Fink <werner@suse.de>
- Require new package libpaper-tools (boo#1202402) instead of
  old package paper
* Thu Mar 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to 2.08:
  * man pages: names of programs should always start with
    lower-case letter
  * PSUtils.pm: update invocation of paper, and improve parsing of
    output
- Changes from 2.07:
  * PSUtils.pm: add trailing colon to certain DSC keywords
- Changes from 2.06:
  * Fix normalization of rotations in pagespecs
  * PSUtils.pm: in parsepaper, don’t pass empty string to
    singledimension
- Changes from 2.05:
  * PSUtils.pm: print the culprit when we get a bad dimension
  * Make programs use bindir prefix when running each other
  * Fix a bug in test harness: don’t distribute built file
    pre-inst-env
  * tests: remove accidentally-added file
  * Makefile.am: don’t echo an echo command in “make loc”
- Use current macros.
* Sat Jan 30 2021 Dirk Müller <dmueller@suse.com>
- update to 2.04:
  * pstops: fix ability to use paper size in x/y offsets
  * pstops: fix a warning
* Tue Sep 22 2020 Dr. Werner Fink <werner@suse.de>
- The previous update makes trhe patches
  * psutils-flip.dif (is part of upstream now)
  * psutils-p17.dif (does not apply due move from C to perl)
  * psutils-pserror.dif (does not apply due move from C to perl)
  obsolete
* Thu Sep 17 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to v2.03 (no changelog)
* Fri Apr  5 2013 idonmez@suse.com
- Cleanup spec file
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Jan  5 2010 jengelh@medozas.de
- enable parallel build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
* Mon Apr  4 2005 werner@suse.de
- Harden message function to avoid buffer overflows  (bug #75721)
* Wed Jun 16 2004 werner@suse.de
- Add some paper names and sizes (bug #42105)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Fri Jul 11 2003 garloff@suse.de
- use RPM_OPT_FLAGS
* Tue May 27 2003 coolo@suse.de
- use BuildRoot
* Mon Sep 16 2002 sbrabec@suse.cz
- Added psutils-flip.dif patch, which implements page flipping to
  pstops.
* Fri Aug 30 2002 werner@suse.de
- Add comment what to use if psmerge fails
* Thu Dec 14 2000 werner@suse.de
- Group tag
* Mon May 29 2000 kukuk@suse.de
- Use doc macro
* Mon Jan 24 2000 werner@suse.de
- Fix getafm
  - Avoid SIGSEGV in psselect with empty page range
  - Fix man page of pstops
  - Use RPM_OPT_FLAGS
  - /usr/man -> /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sun Nov 16 1997 werner@suse.de
- Update to new version
  - Fix some programs
  * epsffit.c (make showpage work even if inner graphics redefine showpage)
  * psnup.c (remove nasty compile warnings)
  * psutil.c (POSIX conform file position check even if pipes are used)
